#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "terrain.h"
#include "case.h"

/*!
* \file joueurList.c
* \brief Fichier contenant le code des fonctions liees aux types de terrains.
*/


/*!
 * \fn Terrain* Librairie_Terrains(char *filename)
 * \brief Procdure de remplissage des cases  partir d'un fichier XML.
 *
 * \param Un nom de fichier XML.
 * \return Un tableau de Terrains.
 */
Terrain* Librairie_Terrains(char *filename)
{
    return Remplir_Terrains_log(filename);
}

/*!
 * \fn Terrain* Remplir_Terrains_log(char *filename)
 * \brief Generation d'un fichier log decrivant le deroulement de la procedure d'aquisition des terrains.
 *
 * \param Un nom de fichier XML.
 * \return Un tableau de Terrains.
 */
Terrain* Remplir_Terrains_log(char *filename)
{

    FILE* Terrains_log = NULL;
    Terrains_log = fopen("Terrains_XML_log", "w");
    if (Terrains_log != NULL)
    {
        Terrain *Tab_terrain;
        fprintf(Terrains_log,"Fichier decrivant le deroulement de la procedure d'acquisition des Terrains\n\n");
        Tab_terrain = Remplir_Terrains(Terrains_log, filename);

        fclose(Terrains_log);
        return Tab_terrain;
    }
    else
    {
        fprintf(stderr,"Impossible d'ouvrir le fichier Terrains_XML_log");
        return NULL;
    }
}

/*!
 * \fn boolean terrain_franchissable(Terrain *t)
 * \brief La fonction retourne le fait que le terrain soit franchissable ou non.
 *
 * \param Un pointeur sur un terrain.
 * \return Un booleen.
 */
boolean terrain_franchissable(Terrain *t){
    return t->franchissable;
}

/*!
 * \fn Terrain * init_terrain(Terrain * t, char * n, boolean f, unsigned short int PD)
 * \brief La fonction initialise un terrain.
 *
 * \param Un pointeur sur un terrain, une chaine de caracteres, un boolean, un entier.
 * \return Un Terrain.
 */
Terrain * init_terrain(Terrain * t, char * n, boolean f, unsigned short int PD){
    t->franchissable=f;
    strncpy(n,t->nomTerrain,TAILLE_NOMS-1);
    t->nomTerrain[0]='\0';
    t->PD_requis=PD;
    return t;
}
